version 9.2

* This file does the event study for the Geithner tax problem event
* Output goes into a file "Event Study Output tax.dta"


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


use "Return Data.dta", clear

set more off

reshape long ri, i(index) j(day) string
gen statadate=date(day,"dm20y")
gen event_date=17911  /* 17910 is Jan. 13, 2009, tax mistakes revealed by senate committee after 4pm */

* drop stock market holidays between Jul07 to Feb09

drop if statadate==17351 |statadate==17412 |statadate==17492 |statadate==17525 |statadate==17532 |statadate==17552 | statadate==17580 |statadate==17612 | statadate==17678 | statadate==17717 | statadate==17776 | statadate==17863 | statadate==17891 | statadate==17898 | statadate==17916 | statadate==17944 


* create difference from event date

sort index statadate
by index: gen datenum=_n
by index: gen target=datenum if statadate==event_date
egen td=min(target), by(index)
drop target
gen dif=datenum-td
drop datenum td


* create returns from return index

sort index statadate
by index: gen ret=(ri-ri[_n-1])/ri[_n-1]


* choose event window and estimation window

by index: gen event_window=1 if dif>=0 & dif<=10 & ~(ret==.)
egen count_event_obs=count(event_window), by(index)
by index: gen estimation_window=1 if dif>=-280 & dif<-30 & ~(ret==.)
egen count_est_obs=count(estimation_window), by(index)
drop if count_est_obs<225
drop if count_event_obs<11


* generate market returns

save "Event Study Output tax.dta", replace
keep if index==679 /* assuming appropriate market index is in row after == */
rename ret market_return
keep statadate market_return
sort statadate 
save "Merge.dta", replace
use "Event Study Output tax.dta", clear
sort statadate 
merge statadate using "Merge.dta"
drop if _merge==2
drop _merge
erase "Merge.dta"

* this puts in the 3pm to 4pm returns for Nov. 21

sort ticker
merge ticker using "Return Nov. 21 Data.dta"
drop if _merge==2
drop _merge


* calculate predicted returns

gen predicted_return=.
egen id=group(index)

forvalues i=1(1)666 {
 quietly reg ret market_return if id==`i' & estimation_window==1
 predict p if id==`i'
 replace predicted_return = p if id==`i' & event_window==1
 drop p
}


* calculate abnormal returns

sort index statadate
gen abnormal_return=ret-predicted_return if event_window==1
replace abnormal_return=0 if abnormal_return==.
gen abnormal_return_temp=abnormal_return
by index: egen CAR0to10 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==10
by index: egen CAR0to9 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==9
by index: egen CAR0to8 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==8
by index: egen CAR0to7 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==7
by index: egen CAR0to6 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==6
by index: egen CAR0to5 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==5
by index: egen CAR0to4 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==4
by index: egen CAR0to3 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==3
by index: egen CAR0to2 = sum(abnormal_return_temp)
replace abnormal_return_temp=0 if dif==2
by index: egen CAR0to1 = sum(abnormal_return_temp)
drop abnormal_return_temp


* prepare output for merging with master file

drop if event_window==.
drop  event_window count_event_obs estimation_window count_est_obs market_return predicted_return id ri event_date
rename index index_ds
label var index_ds "Index from Datastream download, BANKS.LLT"
rename day date_ds
drop statadate

reshape wide date_ds ret abnormal_return, i(index_ds) j(dif)
sort index
drop in l

label var index_ds "ordering from Datastream from banks.LLT, 1-678
label var date_ds0 "date of stock return
label var ret0 "raw return on event day 0
label var abnormal_return0 "abnormal return on event day 0
label var date_ds1 "date of stock return
label var ret1 "raw return on event day 1
label var abnormal_return1 "abnormal return on event day 1
label var date_ds2 "date of stock return
label var ret2 "raw return on event day 2
label var abnormal_return2 "abnormal return on event day 2
label var date_ds3 "date of stock return
label var ret3 "raw return on event day 3
label var abnormal_return3 "abnormal return on event day 3
label var date_ds4 "date of stock return
label var ret4 "raw return on event day 4
label var abnormal_return4 "abnormal return on event day 4
label var date_ds5 "date of stock return
label var ret5 "raw return on event day 5
label var abnormal_return5 "abnormal return on event day 5
label var date_ds6 "date of stock return
label var ret6 "raw return on event day 6
label var abnormal_return6 "abnormal return on event day 6
label var date_ds7 "date of stock return
label var ret7 "raw return on event day 7
label var abnormal_return7 "abnormal return on event day 7
label var date_ds8 "date of stock return
label var ret8 "raw return on event day 8
label var abnormal_return8 "abnormal return on event day 8
label var date_ds9 "date of stock return
label var ret9 "raw return on event day 9
label var abnormal_return9 "abnormal return on event day 9
label var date_ds10 "date of stock return
label var ret10 "raw return on event day 10
label var abnormal_return10 "abnormal return on event day 10
label var CAR0to10 "cumulative abnormal return event day 0 to 10
label var CAR0to9 "cumulative abnormal return event day 0 to 9
label var CAR0to8 "cumulative abnormal return event day 0 to 8
label var CAR0to7 "cumulative abnormal return event day 0 to 7
label var CAR0to6 "cumulative abnormal return event day 0 to 6
label var CAR0to5 "cumulative abnormal return event day 0 to 5
label var CAR0to4 "cumulative abnormal return event day 0 to 4
label var CAR0to3 "cumulative abnormal return event day 0 to 3
label var CAR0to2 "cumulative abnormal return event day 0 to 2
label var CAR0to1 "cumulative abnormal return event day 0 to 1

save "Event Study Output tax.dta", replace

