version 9.2

* This file assumes that the file "create correlations.do" has already been run. This puts correlations with Citi into an output file called "citicorr.dta".
* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"

* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City


sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge
label variable citicorr "return correlation with Citigroup
label variable citicorr_90th "90th percentile in Citi correlation

* Create dummy variables from connections data

gen geithnersched=0
replace geithnersched=1 if geithnerschednum>0 & ~(geithnerschednum==.)
gen geithner2=0
replace geithner2=1 if geithner2num>0 & ~(geithner2num==.)


* Calculate actual return for days 0 through 10

gen ret0to10=((1+ret0)*(1+ret1)*(1+ret2)*(1+ret3)*(1+ret4)*(1+ret5)*(1+ret6)*(1+ret7)*(1+ret8)*(1+ret9)*(1+ret10))-1


* Panel A
by geithnersched, sort: summ ret0 if citicorr<=citicorr_90th, detail
ranksum ret0 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret1 if citicorr<=citicorr_90th, detail
ranksum ret1 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret2 if citicorr<=citicorr_90th, detail
ranksum ret2 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret3 if citicorr<=citicorr_90th, detail
ranksum ret3 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret4 if citicorr<=citicorr_90th, detail
ranksum ret4 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret5 if citicorr<=citicorr_90th, detail
ranksum ret5 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret6 if citicorr<=citicorr_90th, detail
ranksum ret6 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret7 if citicorr<=citicorr_90th, detail
ranksum ret7 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret8 if citicorr<=citicorr_90th, detail
ranksum ret8 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret9 if citicorr<=citicorr_90th, detail
ranksum ret9 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret10 if citicorr<=citicorr_90th, detail
ranksum ret10 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ ret0to10 if citicorr<=citicorr_90th, detail
ranksum ret0to10 if citicorr<=citicorr_90th, by(geithnersched)

by geithner2, sort: summ ret0 if citicorr<=citicorr_90th, detail
ranksum ret0 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret1 if citicorr<=citicorr_90th, detail
ranksum ret1 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret2 if citicorr<=citicorr_90th, detail
ranksum ret2 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret3 if citicorr<=citicorr_90th, detail
ranksum ret3 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret4 if citicorr<=citicorr_90th, detail
ranksum ret4 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret5 if citicorr<=citicorr_90th, detail
ranksum ret5 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret6 if citicorr<=citicorr_90th, detail
ranksum ret6 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret7 if citicorr<=citicorr_90th, detail
ranksum ret7 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret8 if citicorr<=citicorr_90th, detail
ranksum ret8 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret9 if citicorr<=citicorr_90th, detail
ranksum ret9 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret10 if citicorr<=citicorr_90th, detail
ranksum ret10 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ ret0to10 if citicorr<=citicorr_90th, detail
ranksum ret0to10 if citicorr<=citicorr_90th, by(geithner2)

by ny, sort: summ ret0 if citicorr<=citicorr_90th, detail
ranksum ret0 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret1 if citicorr<=citicorr_90th, detail
ranksum ret1 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret2 if citicorr<=citicorr_90th, detail
ranksum ret2 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret3 if citicorr<=citicorr_90th, detail
ranksum ret3 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret4 if citicorr<=citicorr_90th, detail
ranksum ret4 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret5 if citicorr<=citicorr_90th, detail
ranksum ret5 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret6 if citicorr<=citicorr_90th, detail
ranksum ret6 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret7 if citicorr<=citicorr_90th, detail
ranksum ret7 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret8 if citicorr<=citicorr_90th, detail
ranksum ret8 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret9 if citicorr<=citicorr_90th, detail
ranksum ret9 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret10 if citicorr<=citicorr_90th, detail
ranksum ret10 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ ret0to10 if citicorr<=citicorr_90th, detail
ranksum ret0to10 if citicorr<=citicorr_90th, by(ny)


* Panel B

by geithnersched, sort: summ abnormal_return0 if citicorr<=citicorr_90th, detail
ranksum abnormal_return0 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to1 if citicorr<=citicorr_90th, detail
ranksum CAR0to1 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to2 if citicorr<=citicorr_90th, detail
ranksum CAR0to2 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to3 if citicorr<=citicorr_90th, detail
ranksum CAR0to3 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to4 if citicorr<=citicorr_90th, detail
ranksum CAR0to4 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to5 if citicorr<=citicorr_90th, detail
ranksum CAR0to5 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to6 if citicorr<=citicorr_90th, detail
ranksum CAR0to6 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to7 if citicorr<=citicorr_90th, detail
ranksum CAR0to7 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to8 if citicorr<=citicorr_90th, detail
ranksum CAR0to8 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to9 if citicorr<=citicorr_90th, detail
ranksum CAR0to9 if citicorr<=citicorr_90th, by(geithnersched)
by geithnersched, sort: summ CAR0to10 if citicorr<=citicorr_90th, detail
ranksum CAR0to10 if citicorr<=citicorr_90th, by(geithnersched)

by geithner2, sort: summ abnormal_return0 if citicorr<=citicorr_90th, detail
ranksum abnormal_return0 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to1 if citicorr<=citicorr_90th, detail
ranksum CAR0to1 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to2 if citicorr<=citicorr_90th, detail
ranksum CAR0to2 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to3 if citicorr<=citicorr_90th, detail
ranksum CAR0to3 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to4 if citicorr<=citicorr_90th, detail
ranksum CAR0to4 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to5 if citicorr<=citicorr_90th, detail
ranksum CAR0to5 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to6 if citicorr<=citicorr_90th, detail
ranksum CAR0to6 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to7 if citicorr<=citicorr_90th, detail
ranksum CAR0to7 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to8 if citicorr<=citicorr_90th, detail
ranksum CAR0to8 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to9 if citicorr<=citicorr_90th, detail
ranksum CAR0to9 if citicorr<=citicorr_90th, by(geithner2)
by geithner2, sort: summ CAR0to10 if citicorr<=citicorr_90th, detail
ranksum CAR0to10 if citicorr<=citicorr_90th, by(geithner2)

by ny, sort: summ abnormal_return0 if citicorr<=citicorr_90th, detail
ranksum abnormal_return0 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to1 if citicorr<=citicorr_90th, detail
ranksum CAR0to1 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to2 if citicorr<=citicorr_90th, detail
ranksum CAR0to2 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to3 if citicorr<=citicorr_90th, detail
ranksum CAR0to3 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to4 if citicorr<=citicorr_90th, detail
ranksum CAR0to4 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to5 if citicorr<=citicorr_90th, detail
ranksum CAR0to5 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to6 if citicorr<=citicorr_90th, detail
ranksum CAR0to6 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to7 if citicorr<=citicorr_90th, detail
ranksum CAR0to7 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to8 if citicorr<=citicorr_90th, detail
ranksum CAR0to8 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to9 if citicorr<=citicorr_90th, detail
ranksum CAR0to9 if citicorr<=citicorr_90th, by(ny)
by ny, sort: summ CAR0to10 if citicorr<=citicorr_90th, detail
ranksum CAR0to10 if citicorr<=citicorr_90th, by(ny)



erase "Master Data.dta"
