version 9.2

* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".
* This file calculates abnormal returns for the estimation window in order to create the pre-event correlation matrix (sigma)
* Output goes into a file "residuals ttest raw.dta"


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


set more off
clear
set maxvar 10000

use "Return Data.dta", clear




reshape long ri, i(index) j(day) string
gen statadate=date(day,"dm20y")
gen event_date=17857  /* 17857 is Nov 21, 2008: Geithner nomination first leaked */


* drop stock market holidays

drop if statadate==17351 |statadate==17412 |statadate==17492 |statadate==17525 |statadate==17532 |statadate==17552 | statadate==17580 |statadate==17612 | statadate==17678 | statadate==17717 | statadate==17776 | statadate==17863 | statadate==17891 | statadate==17898 | statadate==17916 | statadate==17944 |statadate==17997


* create difference from event date

sort index statadate
by index: gen datenum=_n
by index: gen target=datenum if statadate==event_date
egen td=min(target), by(index)
drop target
gen dif=datenum-td
drop datenum td


* create returns from return index

sort index statadate
by index: gen ret=(ri-ri[_n-1])/ri[_n-1]


* choose event window and estimation window

by index: gen event_window=1 if dif>=0 & dif<=10 & ~(ret==.)
egen count_event_obs=count(event_window), by(index)
by index: gen estimation_window=1 if dif>=-280 & dif<-30 & ~(ret==.)
egen count_est_obs=count(estimation_window), by(index)


* generate market returns

save "residuals ttest raw.dta", replace
keep if index==679 /* assuming appropriate market index is ind row after == */
rename ret market_return
keep statadate market_return
sort statadate 
save "Merge.dta", replace
use "residuals ttest raw.dta", clear
sort statadate 
merge statadate using "Merge.dta"
drop if _merge==2
drop _merge


* this puts in the 3pm to 4pm returns for Nov. 21

sort ticker
merge ticker using "Return Nov. 21 Data.dta"
drop if _merge==2
drop _merge
replace ret=ret3to4 if dif==0
replace market_return=.06876978 if dif==0 /* this is the S&P 500 return from 3to4 on Nov 21 */
drop ret3to4  




* prepare output for merging with master file 

drop if estimation_window==.
drop  event_window count_event_obs estimation_window count_est_obs market_return ri event_date
rename index index_ds
label var index_ds "Index from Datastream download, BANKS.LLT"
rename day date_ds
drop statadate
replace dif=-dif

reshape wide date_ds ret, i(index_ds) j(dif)
sort index
drop in l


label var index_ds "ordering from Datastream from banks.LLT, 1-678

* merge in financial data

save "residuals ttest raw.dta", replace
use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "residuals ttest raw.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge

sort ticker
merge ticker using "bofacorr.dta"
drop if _merge==2
drop _merge 

*   This one uses one-day returns, full sample

forvalues i=280(-1)31 {
 reg ret`i'   if fullsample==1
predict residfulloneraw`i', residuals
replace residfulloneraw`i'=0 if residfulloneraw`i'==.
}


*   This one uses one-day returns, base sample

forvalues i=280(-1)31 {
 reg ret`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbaseoneraw`i', residuals
replace residbaseoneraw`i'=0 if residbaseoneraw`i'==.
}


*   This one uses day 0-10 returns, full sample

forvalues i=280(-1)41 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8
local r=`i'-9
local s=`i'-10
gen ret0to10`i'=((1+ret`i')*(1+ret`j')*(1+ret`k')*(1+ret`l')*(1+ret`m')*(1+ret`n')*(1+ret`o')*(1+ret`p')*(1+ret`q')*(1+ret`r')*(1+ret`s'))-1
 reg ret0to10`i'   if fullsample==1
predict residfulltenraw`i', residuals
replace residfulltenraw`i'=0 if residfulltenraw`i'==.
drop ret0to10`i'
}


*   This one uses day 0-10 returns, base sample

forvalues i=280(-1)41 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8
local r=`i'-9
local s=`i'-10
gen ret0to10`i'=((1+ret`i')*(1+ret`j')*(1+ret`k')*(1+ret`l')*(1+ret`m')*(1+ret`n')*(1+ret`o')*(1+ret`p')*(1+ret`q')*(1+ret`r')*(1+ret`s'))-1

 reg ret0to10`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbasetenraw`i', residuals
replace residbasetenraw`i'=0 if residbasetenraw`i'==.
drop ret0to10`i'
}


sort ticker
drop bofacorr citicorr bofacorr_90th citicorr_90th
save "residuals ttest raw.dta", replace

