version 9.2

* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".
* This file calculates abnormal returns for the estimation window in order to create the pre-event correlation matrix (sigma)
* Output goes into a file "residuals ttest.dta"


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


set more off
clear
set maxvar 10000

use "Return Data.dta", clear




reshape long ri, i(index) j(day) string
gen statadate=date(day,"dm20y")
gen event_date=17857  /* 17857 is Nov 21, 2008: Geithner nomination first leaked */


* drop stock market holidays

drop if statadate==17351 |statadate==17412 |statadate==17492 |statadate==17525 |statadate==17532 |statadate==17552 | statadate==17580 |statadate==17612 | statadate==17678 | statadate==17717 | statadate==17776 | statadate==17863 | statadate==17891 | statadate==17898 | statadate==17916 | statadate==17944 |statadate==17997


* create difference from event date

sort index statadate
by index: gen datenum=_n
by index: gen target=datenum if statadate==event_date
egen td=min(target), by(index)
drop target
gen dif=datenum-td
drop datenum td


* create returns from return index

sort index statadate
by index: gen ret=(ri-ri[_n-1])/ri[_n-1]


* choose event window and estimation window

by index: gen event_window=1 if dif>=0 & dif<=10 & ~(ret==.)
egen count_event_obs=count(event_window), by(index)
by index: gen estimation_window=1 if dif>=-280 & dif<-30 & ~(ret==.)
egen count_est_obs=count(estimation_window), by(index)


* generate market returns

save "residuals ttest.dta", replace
keep if index==679 /* assuming appropriate market index is ind row after == */
rename ret market_return
keep statadate market_return
sort statadate 
save "Merge.dta", replace
use "residuals ttest.dta", clear
sort statadate 
merge statadate using "Merge.dta"
drop if _merge==2
drop _merge


* this puts in the 3pm to 4pm returns for Nov. 21

sort ticker
merge ticker using "Return Nov. 21 Data.dta"
drop if _merge==2
drop _merge
replace ret=ret3to4 if dif==0
replace market_return=.06876978 if dif==0 /* this is the S&P 500 return from 3to4 on Nov 21 */
drop ret3to4  


* calculate predicted returns

gen predicted_return=.
egen id=group(index)

forvalues i=1(1)666 {
 reg ret market_return if id==`i' & estimation_window==1
 predict p if id==`i'
 replace predicted_return = p if id==`i' & estimation_window==1
 drop p
}


* calculate abnormal returns

sort index statadate
gen abnormal_return=ret-predicted_return if estimation_window==1
replace abnormal_return=0 if abnormal_return==.


* prepare output for merging with master file 

drop if estimation_window==.
drop  event_window count_event_obs estimation_window count_est_obs market_return predicted_return id ri event_date
rename index index_ds
label var index_ds "Index from Datastream download, BANKS.LLT"
rename day date_ds
drop statadate
replace dif=-dif

reshape wide date_ds ret abnormal_return, i(index_ds) j(dif)
sort index
drop in l


label var index_ds "ordering from Datastream from banks.LLT, 1-678

* merge in financial data

save "residuals ttest.dta", replace
use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "residuals ttest.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge

sort ticker
merge ticker using "bofacorr.dta"
drop if _merge==2
drop _merge 

*   This one uses one-day returns, full sample

forvalues i=280(-1)31 {
 reg abnormal_return`i'   if fullsample==1
predict residfullone`i', residuals
replace residfullone`i'=0 if residfullone`i'==.
}


*   This one uses one-day returns, base sample

forvalues i=280(-1)31 {
 reg abnormal_return`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbaseone`i', residuals
replace residbaseone`i'=0 if residbaseone`i'==.
}


*   This one uses two-day returns, base sample
forvalues i=280(-1)32 {
local j=`i'-1

gen CAR0to1`i'=abnormal_return`i' + abnormal_return`j'
 reg CAR0to1`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbasetwo`i', residuals
replace residbasetwo`i'=0 if residbasetwo`i'==.
drop CAR0to1`i'
}


*   This one uses two-day returns, full sample
forvalues i=280(-1)32 {
local j=`i'-1

gen CAR0to1`i'=abnormal_return`i' + abnormal_return`j'
 reg CAR0to1`i'   if fullsample==1
predict residfulltwo`i', residuals
replace residfulltwo`i'=0 if residfulltwo`i'==.
drop CAR0to1`i'
}

* This one uses three-day returns, base sample

forvalues i=280(-1)33 {
local j=`i'-1
local k=`i'-2


gen CAR0to2`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' 
 reg CAR0to2`i'   if fullsample==1 & citicorr<citicorr_90th 
predict residbasethree`i', residuals
replace residbasethree`i'=0 if residbasethree`i'==.
drop CAR0to2`i'
}


* This one uses three-day returns, full sample

forvalues i=280(-1)33 {
local j=`i'-1
local k=`i'-2


gen CAR0to2`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' 
 reg CAR0to2`i'   if fullsample==1 
predict residfullthree`i', residuals
replace residfullthree`i'=0 if residfullthree`i'==.
drop CAR0to2`i'
}


* This one uses four-day returns, base sample

forvalues i=280(-1)34 {
local j=`i'-1
local k=`i'-2
local l=`i'-3

gen CAR0to3`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l'
 reg CAR0to3`i'   if fullsample==1 & citicorr<citicorr_90th 
predict residbasefour`i', residuals
replace residbasefour`i'=0 if residbasefour`i'==.
drop CAR0to3`i'
}


* This one uses four-day returns, full sample

forvalues i=280(-1)34 {
local j=`i'-1
local k=`i'-2
local l=`i'-3

gen CAR0to3`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l'
 reg CAR0to3`i'   if fullsample==1 
predict residfullfour`i', residuals
replace residfullfour`i'=0 if residfullfour`i'==.
drop CAR0to3`i'
}


* This one uses five-day returns, base sample

forvalues i=280(-1)35 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4


gen CAR0to4`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' 
 reg CAR0to4`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbasefive`i', residuals
replace residbasefive`i'=0 if residbasefive`i'==.
drop CAR0to4`i'
}



* This one uses five-day returns, full sample

forvalues i=280(-1)35 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4


gen CAR0to4`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m'
 reg CAR0to4`i'   if fullsample==1
predict residfullfive`i', residuals
replace residfullfive`i'=0 if residfullfive`i'==.
drop CAR0to4`i'
}
* This one uses six-day returns, base sample

forvalues i=280(-1)36 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5


gen CAR0to5`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' 
 reg CAR0to5`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbasesix`i', residuals
replace residbasesix`i'=0 if residbasesix`i'==.
drop CAR0to5`i'
}



* This one uses six-day returns, full sample

forvalues i=280(-1)36 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5


gen CAR0to5`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' 
 reg CAR0to5`i'   if fullsample==1
predict residfullsix`i', residuals
replace residfullsix`i'=0 if residfullsix`i'==.
drop CAR0to5`i'
}
* This one uses seven-day returns, base sample

forvalues i=280(-1)37 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6


gen CAR0to6`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' 
 reg CAR0to6`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbaseseven`i', residuals
replace residbaseseven`i'=0 if residbaseseven`i'==.
drop CAR0to6`i'
}



* This one uses seven-day returns, full sample

forvalues i=280(-1)37 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6


gen CAR0to6`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' 
 reg CAR0to6`i'   if fullsample==1
predict residfullseven`i', residuals
replace residfullseven`i'=0 if residfullseven`i'==.
drop CAR0to6`i'
}
* This one uses eight-day returns, base sample

forvalues i=280(-1)38 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7


gen CAR0to7`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p'
 reg CAR0to7`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbaseeight`i', residuals
replace residbaseeight`i'=0 if residbaseeight`i'==.
drop CAR0to7`i'
}



* This one uses eight-day returns, full sample

forvalues i=280(-1)38 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7


gen CAR0to7`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p' 
 reg CAR0to7`i'   if fullsample==1
predict residfulleight`i', residuals
replace residfulleight`i'=0 if residfulleight`i'==.
drop CAR0to7`i'
}
* This one uses nine-day returns, base sample

forvalues i=280(-1)39 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8


gen CAR0to8`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p' + abnormal_return`q' 
 reg CAR0to8`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbasenine`i', residuals
replace residbasenine`i'=0 if residbasenine`i'==.
drop CAR0to8`i'
}



* This one uses nine-day returns, full sample

forvalues i=280(-1)39 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8


gen CAR0to8`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p' + abnormal_return`q' 
 reg CAR0to8`i'   if fullsample==1
predict residfullnine`i', residuals
replace residfullnine`i'=0 if residfullnine`i'==.
drop CAR0to8`i'
}
* This one uses ten-day returns, base sample

forvalues i=280(-1)40 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8
local r=`i'-9


gen CAR0to9`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p' + abnormal_return`q' + abnormal_return`r' 
 reg CAR0to9`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbaseten`i', residuals
replace residbaseten`i'=0 if residbaseten`i'==.
drop CAR0to9`i'
}



* This one uses ten-day returns, full sample

forvalues i=280(-1)40 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8
local r=`i'-9


gen CAR0to9`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p' + abnormal_return`q' + abnormal_return`r' 
 reg CAR0to9`i'   if fullsample==1
predict residfullten`i', residuals
replace residfullten`i'=0 if residfullten`i'==.
drop CAR0to9`i'
}

* This one uses eleven-day returns, base sample

forvalues i=280(-1)41 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8
local r=`i'-9
local s=`i'-10

gen CAR0to10`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p' + abnormal_return`q' + abnormal_return`r' + abnormal_return`s' 
 reg CAR0to10`i'   if fullsample==1 & citicorr<citicorr_90th
predict residbaseeleven`i', residuals
replace residbaseeleven`i'=0 if residbaseeleven`i'==.
drop CAR0to10`i'
}



* This one uses eleven-day returns, full sample

forvalues i=280(-1)41 {
local j=`i'-1
local k=`i'-2
local l=`i'-3
local m=`i'-4
local n=`i'-5
local o=`i'-6
local p=`i'-7
local q=`i'-8
local r=`i'-9
local s=`i'-10

gen CAR0to10`i'=abnormal_return`i' + abnormal_return`j' + abnormal_return`k' + abnormal_return`l' + abnormal_return`m' + abnormal_return`n' + abnormal_return`o' + abnormal_return`p' + abnormal_return`q' + abnormal_return`r' + abnormal_return`s' 
 reg CAR0to10`i'   if fullsample==1
predict residfulleleven`i', residuals
replace residfulleleven`i'=0 if residfulleleven`i'==.
drop CAR0to10`i'
}

sort ticker
drop bofacorr citicorr bofacorr_90th citicorr_90th
save "residuals ttest.dta", replace

